#
# spec file for package python-django-push-notifications
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-django-push-notifications
Version:        3.0.2
Release:        2.1
Summary:        Django package to send push notifications to mobile devices
License:        MIT
URL:            https://github.com/jazzband/django-push-notifications
Source:         https://files.pythonhosted.org/packages/source/d/django-push-notifications/django-push-notifications-%{version}.tar.gz
Patch0:         support-new-apns2.patch
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 1.11
Requires:       python-pywebpush >= 1.3.0
Suggests:       python-apns2 >= 0.3.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Django >= 1.11}
BuildRequires:  %{python_module apns2}
BuildRequires:  %{python_module django-codemod}
BuildRequires:  %{python_module djangorestframework >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest-django}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pywebpush >= 1.3.0}
BuildRequires:  %{python_module wheel}
# /SECTION
%python_subpackages

%description
Send push notifications to mobile devices through GCM, APNS or WNS and
to WebPush (Chrome, Firefox and Opera) in Django.

%prep
%autosetup -p1 -n django-push-notifications-%{version}
djcodemod run --removed-in 4.0 push_notifications/{admin,fields,models}.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export DJANGO_SETTINGS_MODULE=tests.settings
export PYTHONPATH="$(pwd)"
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/push_notifications
%{python_sitelib}/django_push_notifications-%{version}.dist-info

%changelog
* Wed Apr  3 2024 Steve Kowalik <steven.kowalik@suse.com>
- No more greedy globs in %%files.
- Switch back to PyPi tarball, and use setuptools_scm.
* Wed Nov 29 2023 Dirk Müller <dmueller@suse.com>
- update to 3.0.2:
  * LegacyConfig.get_apns_use_alternative_port always return None
  * Add django 4.1, remove master branch
  * Update topic send_message docs in README
  * Fix: HexadecimalField accepts non-hex values
  * Expanded documentation for Web Push
  * Allow APNS tokens of variable length.
  * Add WebPush support for Safari
* Fri Jan  6 2023 Steve Kowalik <steven.kowalik@suse.com>
- Add patch support-new-apns2.patch:
  * Support new apsn2 that no longer exports init_context.
* Wed May 11 2022 pgajdos@suse.com
- version update to 3.0.0
  * #567 Fixes crash on bulk_send test message operation from admin by @DataGreed in #568
  * Updated README: added info about APNS_AUTH_KEY_PATH, APNS_AUTH_KEY_ID, APNS_TEAM_ID by @DataGreed in #566
  * Add some details to APNS settings description by @scherbakovx in #575
  * Django 4.0 warnings by @jheld in #585
  * Run tests on python3.9 by @bertonha in #589
  * add mutable_content to fcm by @paradizer in #582
  * Improve efficiency of ORM lookups by @code-review-doctor in #598
  * Drop python 2.x and django before 2.2 by @sevdog in #599
  * Migrate to GitHub Actions. by @jezdez in #607
  * Mention WebPushDevice in README by @Tyilo in #608
  * Make push optional dependecies by @sevdog in #600
  * fix: Remove python3.5 deps by @bertonha in #621
  * Spelling error & convert string to be translatable by @Andrew-Chen-Wang in #614
  * ++Enable sending image in GCM notifications by @ashishnitinpatil in #624
  * [pre-commit.ci] pre-commit autoupdate by @pre-commit-ci in #625
  * Change feature detection logic for database field by @sevdog in #612
  * Add Edge support to webpush by @simonkern in #631
  * chore: test on Django 4.0 by @bertonha in #638
  * chore: test only active Django versions by @bertonha in #639
  * chore: dry tests, use newer DRF on tests by @bertonha in #641
  * [pre-commit.ci] pre-commit autoupdate by @pre-commit-ci in #635
  * More robust handling of userAgentData, fix WebPushDeviceAdmin by @simonkern in #643
  * [pre-commit.ci] pre-commit autoupdate by @pre-commit-ci in #644
  * Add missing migration for #614 by @simonkern in #645
  * Jazzband: Synced file(s) with jazzband/.github by @jazzband-bot in #626
  * Show coverage badge in README. by @shimakaze-git in #651
- python-mock is not required for build
* Sun Dec 26 2021 John Vandenberg <jayvdb@gmail.com>
- - Use django-codemod to make Django 4 compatible
* Thu Aug  6 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix the tests with updated pytest macros
* Sun Jun  7 2020 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
* Mon May  4 2020 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v2.0.0
